Class: Array

Inherits:
Object
  • Object
show all
Defined in:
lib/acts_as_citable/renderers.rb

Instance Method Summary collapse

Instance Method Details

#to_bibtexObject

Allow array of objects to be translated to ris



8
9
10
# File 'lib/acts_as_citable/renderers.rb', line 8

def to_bibtex
  self.collect { |r| r.to_bibtex if r.respond_to? :to_bibtex }.join("\n\n")
end

#to_risObject

Allow array of objects to be translated to ris



3
4
5
# File 'lib/acts_as_citable/renderers.rb', line 3

def to_ris
  self.collect { |r| r.to_ris if r.respond_to? :to_ris}.join("\n\n")
end